"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChainTransactionMigrator = void 0;
const ChainTransaction_js_1 = require("../../businessObjects/versioned/ChainTransaction.js");
const EVMTransaction_js_1 = require("../../businessObjects/versioned/EVMTransaction.js");
const SolanaTransaction_js_1 = require("../../businessObjects/versioned/SolanaTransaction.js");
const VersionedObject_js_1 = require("../../businessObjects/versioned/VersionedObject.js");
const index_js_1 = require("../../configuration/index.js");
const index_js_2 = require("../../enum/index.js");
class ChainTransactionMigrator extends VersionedObject_js_1.VersionedObjectMigrator {
    getCurrentVersion() {
        return ChainTransaction_js_1.ChainTransaction.CURRENT_VERSION;
    }
    factory(data) {
        switch ((0, index_js_1.getChainInfoByChainId)(data["chainId"]).chainTechnology) {
            case index_js_2.EChainTechnology.Solana:
                return new SolanaTransaction_js_1.SolanaTransaction(data["ChainId"], data["hash"], data["timestamp"], data["slot"], data["err"], data["memo"], data["measurementDate"]);
            case index_js_2.EChainTechnology.EVM:
                return new EVMTransaction_js_1.EVMTransaction(data["chainId"], data["hash"], data["timestamp"], data["blockHeight"], data["to"], data["from"], data["value"], data["gasPrice"], data["contractAddress"], data["input"], data["methodId"], data["functionName"], data["events"], data["measurementDate"]);
            default:
                throw new Error("chain ID does not match known technology");
        }
    }
    getUpgradeFunctions() {
        return new Map([
            [
                1,
                (data, version) => {
                    data["measurementDate"] = Math.floor(Date.now() / 1000);
                    return data;
                },
            ],
        ]);
    }
}
exports.ChainTransactionMigrator = ChainTransactionMigrator;
//# sourceMappingURL=ChainTransactionMigrator.js.map