import { ResultAsync } from "neverthrow";
/**
 * This utility type adds parameters to the end of a function and returns the
 * new function type
 */
export type AddParameters<TFunction extends (...args: unknown[]) => unknown, TParameters extends [...args: unknown[]]> = (...args: [...Parameters<TFunction>, ...TParameters]) => ReturnType<TFunction>;
/**
 * This utility type returns the instantiated template type for the value of
 * a ResultAsync
 */
export type GetResultAsyncValueType<C extends ResultAsync<unknown, unknown>> = C extends ResultAsync<infer T, unknown> ? T : unknown;
/**
 * This utility type returns the instantiated template type for the error of
 * a ResultAsync
 */
export type GetResultAsyncErrorType<C extends ResultAsync<unknown, unknown>> = C extends ResultAsync<unknown, infer T> ? T : unknown;
/**
 * Returns a tuple type appended with a new element on the end
 */
export type AppendTuple<T extends unknown[], E> = [...T, E];
/**
 * Returns a tuple type appended with a new element on the front
 */
export type PrependTuple<T extends unknown[], E> = [E, ...T];
/**
 * Concatenates two tuples types into a single tuple
 */
export type ConcatTuple<T1 extends unknown[], T2 extends unknown[]> = [
    ...T1,
    ...T2
];
/**
 * Removes the first type in the tuple and returns the remaining elements
 */
export type ShiftTuple<T extends unknown[]> = T extends [T[0], ...infer R] ? R : never;
/**
 * Removes the last type in the tuple and returns the remaining elements
 */
export type PopTuple<T extends unknown[]> = T extends [...infer R, infer E] ? R : never;
export type FirstFromTuple<T extends unknown[]> = T["length"] extends 0 ? undefined : T[0];
//# sourceMappingURL=types.d.ts.map